foundation_formtags.tests package
=================================

Submodules
----------

foundation_formtags.tests.forms module
--------------------------------------

.. automodule:: foundation_formtags.tests.forms
    :members:
    :undoc-members:
    :show-inheritance:

foundation_formtags.tests.tests module
--------------------------------------

.. automodule:: foundation_formtags.tests.tests
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: foundation_formtags.tests
    :members:
    :undoc-members:
    :show-inheritance:
